@@ -23,6 +23,7 @@
 #include <QFile>
 #include <QThreadPool>
 
+#include <KDebug>
 #include <KGlobalSettings>
 #include <KUrl>
 #include <KIO/NetAccess>
@@ -39,6 +40,7 @@ Picture::Picture(QObject *parent)
         : QObject(parent)
 {
     m_defaultImage = KGlobal::dirs()->findResource("data", "plasma-applet-frame/picture-frame-default.jpg");
+    m_checkDir = false;
 
     // listen for changes to the file we're displaying
     m_fileWatch = new KDirWatch(this);
@@ -61,6 +63,16 @@ void Picture::setMessage(const QString &message)
     m_message = message;
 }
 
+void Picture::setAllowNullImages(bool allowNull)
+{
+    m_allowNullImages = allowNull;
+}
+
+bool Picture::allowNullImages() const
+{
+    return m_allowNullImages;
+}
+
 QImage Picture::defaultPicture(const QString &message)
 {
     // Create a QImage with same axpect ratio of default svg and current pixelSize
@@ -73,17 +85,19 @@ QImage Picture::defaultPicture(const QString &message)
 void Picture::setPicture(const KUrl &currentUrl)
 {
     m_currentUrl = currentUrl;
-    ImageLoader *loader;
     kDebug() << currentUrl;
-    
+
     if (!m_currentUrl.isEmpty() && !m_currentUrl.isLocalFile()) {
         kDebug() << "Not a local file, downloading" << currentUrl;
-        m_job = KIO::storedGet( currentUrl, KIO::NoReload, KIO::DefaultFlags );
-        connect(m_job, SIGNAL(finished(KJob*)), this, SLOT(slotFinished(KJob*)));
+        KIO::StoredTransferJob * job = KIO::storedGet( currentUrl, KIO::NoReload, KIO::HideProgressInfo);
+        connect(job, SIGNAL(finished(KJob*)), this, SLOT(slotFinished(KJob*)));
         emit pictureLoaded(defaultPicture(i18n("Loading image...")));
     } else {
-        if (currentUrl.isEmpty()) {
-            loader = new ImageLoader(m_defaultImage);
+        ImageLoader *loader = 0;
+        if (m_checkDir) {
+            m_message = i18nc("Info", "Dropped folder is empty. Please drop a folder with image(s)");
+            m_checkDir = false;
+        } else if (currentUrl.isEmpty()) {
             m_message = i18nc("Info", "Put your photo here or drop a folder to start a slideshow");
             kDebug() << "default image ...";
         } else {
@@ -91,6 +105,11 @@ void Picture::setPicture(const KUrl &currentUrl)
             setPath(m_currentUrl.path());
             m_message.clear();
         }
+
+        if (!loader) {
+            loader = new ImageLoader(m_defaultImage);
+        }
+
         connect(loader, SIGNAL(loaded(QImage)), this, SLOT(checkImageLoaded(QImage)));
         QThreadPool::globalInstance()->start(loader);
     }
@@ -116,35 +135,41 @@ void Picture::setPath(const QString &path)
 void Picture::reload()
 {
     kDebug() << "Picture reload";
+    setMessage(QString());
     ImageLoader *loader = new ImageLoader(m_path);
     connect(loader, SIGNAL(loaded(QImage)), this, SLOT(checkImageLoaded(QImage)));
     QThreadPool::globalInstance()->start(loader);
 }
 
+void Picture::customizeEmptyMessage() 
+{
+    m_checkDir = true;
+}
+
 void Picture::slotFinished( KJob *job )
 {
     QString filename = m_currentUrl.fileName();
     QString path = KStandardDirs::locateLocal("cache", "plasma-frame/" +  m_currentUrl.fileName());
     QImage image;
-    
+
     if (job->error()) {
         kDebug() << "Error loading image:" << job->errorString();
         image = defaultPicture(i18n("Error loading image: %1", job->errorString()));
-    } else {
-        image.loadFromData(m_job->data());
+    } else if (KIO::StoredTransferJob * transferJob = qobject_cast<KIO::StoredTransferJob *>(job)) {
+        image.loadFromData(transferJob->data());
         kDebug() << "Successfully downloaded, saving image to" << path;
         m_message.clear();
         image.save(path);
         kDebug() << "Saved to" << path;
         setPath(path);
     }
-    
+
     emit checkImageLoaded(ImageLoader::correctRotation(image, path));
 }
 
-void Picture::checkImageLoaded(QImage newImage)
+void Picture::checkImageLoaded(const QImage &newImage)
 {
-    if ( newImage.isNull()) {
+    if (!m_allowNullImages && newImage.isNull()) {
         emit pictureLoaded(defaultPicture(i18n("Error loading image. Image was probably deleted.")));
     } else {
         emit pictureLoaded(newImage);
